[Reportbug-commits] r652 - in trunk (checks/compare_pseudo-pkgs_lists.py debian/changelog)

morph-guest at users.alioth.debian.org morph-guest at users.alioth.debian.org
Fri Sep 12 05:44:20 UTC 2008


    Date: Friday, September 12, 2008 @ 05:44:19
  Author: morph-guest
Revision: 652

* checks/compare_pseudo-pkgs_lists.py
  - updated location of canonical pseudo-packages list from ftpmaster to
    bugs.d.o; thanks to Josip Rodin for the patch; Closes: #498663

Modified:
  trunk/checks/compare_pseudo-pkgs_lists.py
  trunk/debian/changelog

Modified: trunk/checks/compare_pseudo-pkgs_lists.py
===================================================================
--- trunk/debian/changelog	2008-09-08 21:55:07 UTC (rev 651)
+++ trunk/debian/changelog	2008-09-12 05:44:19 UTC (rev 652)
@@ -46,8 +46,11 @@
     - added buildd.emdebian.org and debian-i18n pseudo-packages
   * man/{querybts.1,reportbug.1,reportbug.conf.5}
     - added UI information; thanks to Luca Bruno's patch
+  * checks/compare_pseudo-pkgs_lists.py
+    - updated location of canonical pseudo-packages list from ftpmaster to
+      bugs.d.o; thanks to Josip Rodin for the patch; Closes: #498663
 
- -- Sandro Tosi <matrixhasu at gmail.com>  Mon, 08 Sep 2008 23:53:51 +0200
+ -- Sandro Tosi <matrixhasu at gmail.com>  Fri, 12 Sep 2008 07:40:34 +0200
 
 reportbug (3.45) unstable; urgency=low
 




More information about the Reportbug-commits mailing list
--- trunk/checks/compare_pseudo-pkgs_lists.py	2008-09-08 21:55:07 UTC (rev 651)
+++ trunk/checks/compare_pseudo-pkgs_lists.py	2008-09-12 05:44:19 UTC (rev 652)
@@ -3,7 +3,7 @@
 # License: Public domain
 #
 # Python script to compare pseudo-packages listed in reportbug
 # agaists the official list on ftp-master
 
 import sys, os
 sys.path = ['.'] + sys.path
@@ -12,27 +12,27 @@
 
 import urllib, re
 
-# separete a sequence of "char not spaces", from at least one space (ftp-master uses tabs), from anything after tabs
+# separete a sequence of "char not spaces", from at least one space (canonical copy uses tabs), from anything after tabs
 # we group the first and the latter, so we get the pseudo-packages name and description
 dictparse = re.compile(r'([^\s]+)\s+(.+)',re.IGNORECASE)
 
-ftpmaster_list = {}
-pseudo = urllib.urlopen('http://ftp-master.debian.org/pseudo-packages.description')
+bdo_list = {}
+pseudo = urllib.urlopen('http://bugs.debian.org/pseudopackages/pseudo-packages.description')
 for l in pseudo:
     m = dictparse.search(l)
-    ftpmaster_list[m.group(1)] = m.group(2)
+    bdo_list[m.group(1)] = m.group(2)
 
 bts_keys=debianbts.debother.keys();
 
-diff_rb_ftp = set(bts_keys)-set(ftpmaster_list)
-diff_ftp_rb = set(ftpmaster_list)-set(bts_keys)
+diff_rb_bdo = set(bts_keys)-set(bdo_list)
+diff_bdo_rb = set(bdo_list)-set(bts_keys)
 
-print "pseudo-pkgs in reportbug not in ftpmaster list:", diff_rb_ftp
+print "pseudo-pkgs in reportbug not in bugs.debian.org list:", diff_rb_bdo
 
-for pkg in diff_rb_ftp:
+for pkg in diff_rb_bdo:
     print "   ", pkg,": ", debianbts.debother[pkg]
 
-print "pseudo-pkgs in ftpmaster list not in reprotbug:", diff_ftp_rb
+print "pseudo-pkgs in bugs.debian.org list not in reportbug:", diff_bdo_rb
 
-for pkg in diff_ftp_rb:
-    print "   ", pkg,": ", ftpmaster_list[pkg]
+for pkg in diff_bdo_rb:
+    print "   ", pkg,": ", bdo_list[pkg]
@@ -3,7 +3,7 @@
 #
 # Python script to compare pseudo-packages listed in reportbug
-# agaists the official list on ftp-master
+# agaists the official list on bugs.debian.org
 
 import sys, os

Modified: trunk/debian/changelog
===================================================================